@@ -6,10 +6,13 @@ from io import BytesIO
 from urllib.parse import parse_qs, urlparse
 
 import boto3
+import requests
 from requests.adapters import BaseAdapter, Response
 
 logger = logging.getLogger(__name__)
 
+DEFAULT_SCHEME = "http+lambda://"
+
 
 def _lambda_query_string(url):
     return {key: value[0] for key, value in parse_qs(urlparse(url).query).items()}
@@ -22,6 +25,12 @@ def decode_payload(lambda_response, field):
         return BytesIO(lambda_response[field].encode("utf-8"))
 
 
+class Session(requests.Session):
+    def __init__(self, url_scheme=None, region=None, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.mount(url_scheme or DEFAULT_SCHEME, LambdaAdapter(region=region))
+
+
 class LambdaAdapter(BaseAdapter):
     def __init__(self, region=None):
         self.region = region or os.environ.get("AWS_DEFAULT_REGION", "us-east-1")
